﻿//____________________________________________________________-


//                       Introduction to Stream Reader in ASP.Net


//                                           Ron Kessler

//                                         Created 2/22/08
//_____________________________________________________________

//Updated 2/25/08

//Updates:
//   Updated to VS2008. 

//NOTES:

//If you want to listbox to work like you expect, then set the autopostback property=true
//features include,
//   How to make a message box on a web form
//   How to iterate through the controls collection
//   How to use stream reader
//   Introduction to the IsPostBack property
//   How to set the root path for the application
//   Reminder about formatting currency



//'==================START OF CODE======================

using System.IO;       //this adds streamreader class


using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;

public partial class Cart : System.Web.UI.Page
{

    //---find the root path of the website and the customer file
    string FileName = System.Web.Hosting.HostingEnvironment.MapPath("~" + "/items.txt");
    const decimal TAXRATE  = 0.075m;

    #region "Page Load"
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)               //only do this stuff on the first creation of the page
        {
            this.btnReturn.Attributes.Add("onclick", "return confirm('Are you sure you want to return?');");
        
            //---add button attributes here
            txtItem.Style.Add("text-align", "right");
            txtPrice.Style.Add("text-align" ,"right");
            txtQuantity.Style.Add("text-align" , "right");
            txtSubtotal.Style.Add("text-align" , "right");
            txtTax.Style.Add("text-align" , "right");
            txtTotal.Style.Add("text-align" , "right");

            GetItems();                    //make sure this is inside the if block 
        }
    }
    #endregion

    #region "Fill the ListBox"
    private void GetItems()
    {

            StreamReader MyReader = new StreamReader(FileName);
            string ItemInFile;
            string Price ;
            string Product;
            lblError.Visible = false;
            
        try
            {
                while (MyReader.Peek() != -1)
                {
                    ItemInFile = MyReader.ReadLine();       //actual text in the file
                    Product = ItemInFile.Substring(0, 10).Trim();    //the first 10 characters are the item
                    Price = ItemInFile.Substring(20).Trim();         //starting at 20 we have the prices

                    //---add the product & price Product is text and price is the value. See items collection in the
                    //properties window for the listbox

                    lstItems.Items.Add(new ListItem(Product, Price));

                }
               
            }

            catch
            {
                lblError.Text = "I can't read the items data file.";
                lblError.Visible = true;
            }

            finally
            {
                MyReader.Close();
            }

    }

    #endregion

    #region "Get Selected Item"
    protected void lstItems_SelectedIndexChanged(object sender, EventArgs e)
    {
        //'---once the text property contains the item and the value property contains the price, grab them!
        txtItem.Text = lstItems.SelectedItem.Text;
        txtPrice.Text = lstItems.SelectedValue;
    }
#endregion

    #region "Check Out"
    protected void btnCheckOut_Click(object sender, EventArgs e)
    {
        //---compute totals & tax and amt due
         try
         {
           lblError.Visible= false;
            //---compute sub total
            decimal subTotal =Convert.ToDecimal(txtPrice.Text) * Convert.ToDecimal(txtQuantity.Text);
             txtSubtotal.Text =subTotal.ToString("n");

            //---compute tax
            decimal tax = subTotal * TAXRATE;
             txtTax.Text = tax.ToString("n");

            //---amount due
            decimal amtDue = subTotal + tax;

            txtTotal.Text = amtDue.ToString("n");

         }
        catch
         {
            lblError.Text = "Please make sure all data is entered correctly....";
            lblError.Visible = true;
        }

        
    }

    #endregion

    #region "Clear Textboxes"
    protected void btnClear_Click(object sender, EventArgs e)
    {

        //form2 is the name of the html form. Look at source view.
        foreach (Control ctrl in Page.FindControl("Form2").Controls)  
        {
            if (ctrl is TextBox)
                
              ((TextBox)ctrl).Text = "";
            
        }



        //master page only
        //foreach (Control ctrl in this.Master.FindControl("ContentPlaceHolder1").Controls)
        //{
        //    if (ctrl is TextBox)

        //        ((TextBox)ctrl).Text = "";

        //}
    }

    #endregion

    #region "Return to main page"
    protected void btnReturn_Click(object sender, EventArgs e)
    {
        Response.Redirect("default.aspx");
    }
    #endregion
}
